Name:           libzrtpcpp
Version:        3.2.1
Release:        2%{?dist}
Summary:        ZRTP support library for the GNU ccRTP stack

Group:          System Environment/Libraries
License:        GPLv3+
URL:            https://github.com/wernerd/ZRTPCPP
Source0:        https://github.com/wernerd/ZRTPCPP/archive/ZRTPCPP-%{version}.tar.gz
# remove ec ecryption, our ssl doesn't ship with it. 
Patch0:         libzrtpcpp-3.2.1-remove-ec.patch
#some of the new headers introduced in libzrtpcpp-3 are incorrectly referenced and
#by matter of consequence are not found by the applications compiled against them
Patch1:		libzrtpcpp-headers.patch
#too many things to modify in the default CMakeLists.txt to rely on sed therefore
#we change it here so as to build the libzrtpcpp library with proper Fedora flags
Source1:        CMakeLists.txt
#per instructions of the author, disable building of zrtptest, it uses a syntax
#not understood by our gcc. included below is a fragment of our correspondance
#
# Regarding the compiler problem: for the time being you can savely skip
# 'zrtptest', the other program that seems to sompile is 'zrtptestMulti' which
# is more elaborate. Can you give me some hint how to define a #ifdef that I
# can use to modify the 'zrtptest' source to exclude some code in for the older
# GCC? I think I can change the code but it takes some time (testing). Thus to
#go forward, just disable building of the 'zrtptest' if possible.
#
Source2:        demo.CmakeLists.txt
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  ccrtp-devel 
BuildRequires:  libgcrypt-devel
BuildRequires:  doxygen
BuildRequires:  cmake
BuildRequires:  openssl-devel

%description
This package provides a library that adds ZRTP support to the GNU
ccRTP stack. Phil Zimmermann developed ZRTP to allow ad-hoc, easy to
use key negotiation to setup Secure RTP (SRTP) sessions. GNU ZRTP
together with GNU ccRTP (1.5.0 or later) provides a ZRTP
implementation that can be directly embedded into client and server
applications.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q -n ZRTPCPP-%{version}
cp -f %{SOURCE1} .
cp -f %{SOURCE2} demo/CMakeLists.txt
#some headers are misplaced; our patch makes the ones from common/ available for
#apps needing libzrtpcpp-devel but unavailable at build time for zrtpcpp itself
mkdir zrtp/libzrtpcpp/common/
cp common/osSpecifics.h zrtp/libzrtpcpp/common/


%patch0 -p1 -b .ec
%patch1 -p1 -b .headers


%build
%cmake .
make %{?_smp_mflags}

# Make the NEWS file non executable
chmod 644 NEWS

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'

%clean
rm -rf $RPM_BUILD_ROOT


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc README.md AUTHORS COPYING NEWS
%{_libdir}/libzrtpcpp.so.3*

%files devel
%defattr(-,root,root,-)
%{_includedir}/libzrtpcpp/
%{_libdir}/libzrtpcpp.so
%{_libdir}/pkgconfig/libzrtpcpp.pc


%changelog
* Mon Aug 05 2013 Manuel "lonely wolf" Wolfshant <wolfy@fedoraproject.org> - 3.2.1-2
- add patch which modifies the new headers introduced by zrtpcpp-3.x so that they can
 actually be used by other applications

* Mon Aug 05 2013 Manuel "lonely wolf" Wolfshant <wolfy@fedoraproject.org> - 3.2.1-1
- new upstream version
 - Fixes CVE-2013-2221 CVE-2013-2222 CVE-2013-2223 and consequently
 https://bugzilla.redhat.com/show_bug.cgi?id=980905

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 21 2012 Kevin Fenzi <kevin@scrye.com> 2.3.2-1
- Update to 2.3.2

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.2-2
- Rebuilt for c++ ABI breakage

* Fri Feb 24 2012 Alexey Kurov <nucleo@fedoraproject.org> - 2.1.2-1
- Update to 2.1.2
- drop upstreamed 64-bit patch
- visibility issue fixed in upstream

* Thu Feb 23 2012 Alexey Kurov <nucleo@fedoraproject.org> - 2.1.1-2
- Workaround for -fvisibility=hidden from commoncpp.pc

* Wed Feb 22 2012 Alexey Kurov <nucleo@fedoraproject.org> - 2.1.1-1
- Update to 2.1.1
- Updated URL

* Tue Feb 21 2012 Dan Horák <dan[at]danny.cz> - 2.0.0-2
- fix build on 64-bit arches

* Sun Jan 22 2012 Kevin Fenzi <kevin@scrye.com> - 2.0.0-1
- Update to 2.0.0

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Apr 07 2009 Kevin Fenzi <kevin@tummy.com> - 1.4.3-1
- Update to 1.4.3 and rebuild against new ccrtp

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jun 30 2008 Kevin Fenzi <kevin@tummy.com> - 1.3.0-2
- Fix unused-direct-shlib-dependency and other minor issues. 

* Wed Jun 25 2008 Kevin Fenzi <kevin@tummy.com> - 1.3.0-1
- Initial version for Fedora

